#
# spec file for package zziplib
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           zziplib
%define lname	libzzip-0-13
Summary:        Free Zip Compression Library with an Easy-to-Use API
License:        LGPL-2.1+
Group:          System/Libraries
Version:        0.13.62
Release:        12.8
Url:            http://zziplib.sourceforge.net
Source0:        http://prdownloads.sourceforge.net/zziplib/%{name}-%{version}.tar.bz2
Source2:        baselibs.conf
Patch:          zziplib-0.13.62.patch
Patch1:         zziplib-0.13.62-wronglinking.patch
Patch2:         zziplib-largefile.patch
Patch3:         zziplib-CVE-2017-5974.patch
Patch4:         zziplib-CVE-2017-5975.patch
Patch5:         zziplib-CVE-2017-5976.patch
Patch6:         zziplib-CVE-2017-5978.patch
Patch7:         zziplib-CVE-2017-5979.patch 
Patch8:         zziplib-unzipcat-NULL-name.patch
Patch9:         zziplib-CVE-2017-5981.patch
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ZZipLib is a library for dealing with zip and zip-like archives by
using free algorithms of zlib.

%package -n %lname
Summary:        Free zip compression library with easy to use API
Group:          System/Libraries
Obsoletes:      zziplib < %version-%release
Provides:       zziplib = %version-%release

%description -n %lname
ZZipLib is a library for dealing with zip and zip-like archives by
using free algorithms of zlib.

%package devel
Summary:        Free zip compression library with easy to use API
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       zlib-devel

%description devel
That are the header files needed for developing applications using
ZZipLib.

%prep
%setup -q
%patch
%patch1
%patch2
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1

# Fix wrong encoding
dos2unix docs/README.MSVC6
dos2unix docs/sdocbook.css

%build
autoreconf -fiv
%configure --with-largefile --enable-frame-pointer --disable-static --with-pic
make %{?_smp_mflags} all;
make doc;

%install
%makeinstall
%{__rm} -f docs/Make* docs/zziplib-manpages.ar
find "%buildroot" -name "*.la" -type f -delete
%fdupes %buildroot

%check 
%{__make} check || exit 0

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%{_libdir}/libzzip*.so.*

%files devel
%defattr(-,root,root)
%doc docs/README* docs/* ChangeLog README TODO 
%{_bindir}/unzzip*
%{_bindir}/zz*
%{_bindir}/unzip-mem
%{_libdir}/libzzip*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*
%{_datadir}/aclocal/*.m4

%changelog
* Thu Mar 23 2017 josef.moellers@suse.com
- Several bugs fixed:
  * heap-based buffer overflows
    (bsc#1024517, CVE-2017-5974, zziplib-CVE-2017-5974.patch)
  * check if "relative offset of local header" in "central
    directory header" really points to a local header
    (ZZIP_FILE_HEADER_MAGIC)
  * protect against bad formatted data in extra blocks
    (bsc#1024531, CVE-2017-5976, zziplib-CVE-2017-5976.patch)
  * NULL pointer dereference in main (unzzipcat-mem.c)
    (bsc#1024532, bsc#1024536/CVE-2017-5980, bsc#1024528,
    CVE-2017-5975, zziplib-CVE-2017-5975.patch)
  * protect against huge values of "extra field length"
    in local file header and central file header
    (bsc#1024533, CVE-2017-5978, zziplib-CVE-2017-5978.patch)
  * clear ZZIP_ENTRY record before use.
    (bsc#1024534, bsc#1024535, CVE-2017-5979, CVE-2017-5977,
    zziplib-CVE-2017-5979.patch)
  * prevent unzzipcat.c from trying to print a NULL name
    (bsc#1024537, zziplib-unzipcat-NULL-name.patch)
  * Replace assert() by going to error exit.
    (bsc#1024539, CVE-2017-5981, zziplib-CVE-2017-5981.patch)
* Sat Mar 16 2013 schwab@linux-m68k.org
- zziplib-largefile.patch: Enable largefile support
- Enable debug information
* Sat Dec 15 2012 p.drouand@gmail.com
- Update to 0.13.62 version:
  * configure.ac: fallback to libtool -export-dynamic unless being sure to
    use gnu-ld --export-dynamic. The darwin case is a bit special here
  as the c-compiler and linker might be from different worlds.
  * Makefile.am: allow nonstaic build
  * wrap fd.open like in the Fedora patch
- Remove the package name on summary
- Add dos2unix as build dependencie to fix a wrong file encoding
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Sep 16 2011 jengelh@medozas.de
- Implement shlib policy/packaging for package, add baselibs.conf
  and resolve redundant constructs
* Sat Apr 30 2011 crrodriguez@opensuse.org
- Fix build with gcc 4.6
* Mon Feb 15 2010 dimstar@opensuse.org
- Update to version 0.13.58:
  + Some bugs fixed, see ChangeLog
* Mon Jul 27 2009 coolo@novell.com
- update to version 0.13.56 - fixes many smaller issues
  (see Changelog)
* Wed Jun 17 2009 coolo@novell.com
- fix build with automake 1.11
* Mon Jan 26 2009 crrodriguez@suse.de
- remove "la" files
* Fri Oct 24 2008 wgottwalt@suse.de
- removed ./msvc7/pkzip.exe and ./msvc8/zip.exe to avoid license
  problems
* Wed Aug 15 2007 crrodriguez@suse.de
- update to version 0.13.49 fixes #260734 buffer overflow
  due to wrong usage of strcpy()
* Thu Mar 29 2007 dmueller@suse.de
- adjust buildrequires
* Mon Dec  4 2006 dmueller@suse.de
- don't build as root
* Tue Oct  3 2006 aj@suse.de
- Fix build.
* Fri Aug 18 2006 aj@suse.de
- Fix build.
* Mon May 22 2006 wgottwalt@suse.de
- initial release
- still problems with the "make check" build option
